@@ -107,7 +107,7 @@ QString KContacts::dateToVCardString(const QDateTime &dateTime)
     return dateTime.toString(QStringLiteral("yyyyMMddThhmmssZ"));
 }
 
-QString KContacts::dateToVCardString(const QDate &date)
+QString KContacts::dateToVCardString(QDate date)
 {
     return date.toString(QStringLiteral("yyyyMMdd"));
 }
@@ -121,12 +121,28 @@ QDateTime KContacts::VCardStringToDate(const QString &dateString)
     d = d.remove(QLatin1Char('-')).remove(QLatin1Char(':'));
 
     if (d.length() >= 8) {
-        date = QDate(d.mid(0, 4).toUInt(), d.mid(4, 2).toUInt(), d.mid(6, 2).toUInt());
+        date = QDate(d.midRef(0, 4).toUInt(), d.midRef(4, 2).toUInt(), d.midRef(6, 2).toUInt());
     }
 
     if (d.length() > 9 && d[ 8 ].toUpper() == QLatin1Char('T')) {
-        time = QTime(d.mid(9, 2).toUInt(), d.mid(11, 2).toUInt(), d.mid(13, 2).toUInt());
+        time = QTime(d.midRef(9, 2).toUInt(), d.midRef(11, 2).toUInt(), d.midRef(13, 2).toUInt());
     }
 
     return QDateTime(date, time);
 }
+
+void KContacts::adaptIMAttributes(QByteArray &data)
+{
+    data.replace("X-messaging/aim-All", ("X-AIM"));
+    data.replace("X-messaging/icq-All", ("X-ICQ"));
+    data.replace("X-messaging/xmpp-All", ("X-JABBER"));
+    data.replace("X-messaging/msn-All", ("X-MSN"));
+    data.replace("X-messaging/yahoo-All", ("X-YAHOO"));
+    data.replace("X-messaging/gadu-All", ("X-GADUGADU"));
+    data.replace("X-messaging/skype-All", ("X-SKYPE"));
+    data.replace("X-messaging/groupwise-All", ("X-GROUPWISE"));
+    data.replace("X-messaging/sms-All", ("X-SMS"));
+    data.replace("X-messaging/meanwhile-All", ("X-MEANWHILE"));
+    data.replace("X-messaging/irc-All", ("X-IRC"));
+    data.replace("X-messaging/googletalk-All", ("X-GTALK"));
+}
